==> jc-1.4.0.tar.gz: gnu/java/nio/charset/US__5fASCII__24Decoder.h <==
// final class gnu.java.nio.charset.US_ASCII$Decoder

// class file dependencies
// @dep_class 6e0e24fa6c5a8e28 gnu_java_nio_charset_US__5fASCII__24Decoder
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4a8409777d0951e1 java_nio_charset_CharsetDecoder

// header file dependencies
// @dep_header java_nio_charset_CharsetDecoder

#include "java/nio/charset/CharsetDecoder.h"

#ifndef _JC_gnu_java_nio_charset_US__5fASCII__24Decoder_H_
#define _JC_gnu_java_nio_charset_US__5fASCII__24Decoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_CharBuffer$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_refs	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_refs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_nonrefs	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$refs	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$refs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$nonrefs	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$nonrefs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object;

typedef const struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vmethods	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vmethods;
typedef const struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtable	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtable;
typedef const struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtype	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtype;

// Constructors
extern void _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$method$_init$a3cee2967eb85389(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object *, struct _jc_java_nio_charset_Charset$object *);

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$method$decodeLoop$5f4fe61acac11663(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object *, struct _jc_java_nio_ByteBuffer$object *, struct _jc_java_nio_CharBuffer$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$method_info$decodeLoop$5f4fe61acac11663;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*decodeLoop$5f4fe61acac11663)(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object *, struct _jc_java_nio_ByteBuffer$object *, struct _jc_java_nio_CharBuffer$object *);
};

// Vtable
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CharsetDecoder$vmethods	java_nio_charset_CharsetDecoder;
	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vmethods	gnu_java_nio_charset_US__5fASCII__24Decoder;
};

// Vtype
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$refs {
    _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_refs	gnu_java_nio_charset_US__5fASCII__24Decoder;
    _jc_java_nio_charset_CharsetDecoder$sub_refs	java_nio_charset_CharsetDecoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CharsetDecoder$sub_nonrefs	java_nio_charset_CharsetDecoder;
    _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_nonrefs	gnu_java_nio_charset_US__5fASCII__24Decoder;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object {
	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtype	*vtype;
	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtype _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_US__5fASCII__24Decoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$class_object;

#endif	/* _JC_gnu_java_nio_charset_US__5fASCII__24Decoder_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/charset/US__5fASCII__24Decoder.h <==
// final class gnu.java.nio.charset.US_ASCII$Decoder

// class file dependencies
// @dep_class 6e0e24fa6c5a8e28 gnu_java_nio_charset_US__5fASCII__24Decoder
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fe28164a0cadaacb java_nio_charset_CharsetDecoder

// header file dependencies
// @dep_header java_nio_charset_CharsetDecoder

#include "java/nio/charset/CharsetDecoder.h"

#ifndef _JC_gnu_java_nio_charset_US__5fASCII__24Decoder_H_
#define _JC_gnu_java_nio_charset_US__5fASCII__24Decoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_CharBuffer$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_refs	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_refs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_nonrefs	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$refs	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$refs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$nonrefs	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$nonrefs;
typedef struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object;

typedef const struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vmethods	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vmethods;
typedef const struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtable	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtable;
typedef const struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtype	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtype;

// Constructors
extern void _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$method$_init$a3cee2967eb85389(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object *, struct _jc_java_nio_charset_Charset$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$method$decodeLoop$5f4fe61acac11663(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object *, struct _jc_java_nio_ByteBuffer$object *, struct _jc_java_nio_CharBuffer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$method_info$decodeLoop$5f4fe61acac11663;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*decodeLoop$5f4fe61acac11663)(_jc_env *, struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object *, struct _jc_java_nio_ByteBuffer$object *, struct _jc_java_nio_CharBuffer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CharsetDecoder$vmethods	java_nio_charset_CharsetDecoder;
	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vmethods	gnu_java_nio_charset_US__5fASCII__24Decoder;
};

// Vtype
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$refs {
    _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_refs	gnu_java_nio_charset_US__5fASCII__24Decoder;
    _jc_java_nio_charset_CharsetDecoder$sub_refs	java_nio_charset_CharsetDecoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CharsetDecoder$sub_nonrefs	java_nio_charset_CharsetDecoder;
    _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$sub_nonrefs	gnu_java_nio_charset_US__5fASCII__24Decoder;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$object {
	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtype	*vtype;
	_jc_gnu_java_nio_charset_US__5fASCII__24Decoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$vtype _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_US__5fASCII__24Decoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_US__5fASCII__24Decoder$class_object;

#endif	/* _JC_gnu_java_nio_charset_US__5fASCII__24Decoder_H_ */
